R/helper_functions.r
explode_multisites.Rd
Each phosphosite goes into its own row when multiple sites are present.
explode_multisites(combined_site)
Data frame with PhosSites column (semicolon-delimited)
Data frame with one row per site, with modAA and posInProtein columns